@@ -1,4 +1,3 @@
-from ckanext.comments.logic.action import CONFIG_REQUIRE_APPROVAL
 import pytest
 
 import ckan.model as model
@@ -6,6 +5,8 @@ import ckan.plugins.toolkit as tk
 import ckan.tests.factories as factories
 from ckan.tests.helpers import call_action
 
+import ckanext.comments.const as const
+
 
 class TestThreadCreate:
     def test_cannot_create_thread_for_missing_object(self):
@@ -196,7 +197,7 @@ class TestCommentCreate:
         )
         assert reply["reply_to_id"] == comment["id"]
 
-    @pytest.mark.ckan_config(CONFIG_REQUIRE_APPROVAL, False)
+    @pytest.mark.ckan_config(const.CONFIG_REQUIRE_APPROVAL, False)
     @pytest.mark.usefixtures("clean_db")
     def test_optional_approval(self, Comment):
         comment = Comment()
@@ -252,8 +253,11 @@ class TestCommentUpdate:
         content = "random content"
         c = Comment()
 
+        assert c["modified_at"] is None
+
         call_action("comments_comment_update", id=c["id"], content=content)
         comment = call_action("comments_comment_show", id=c["id"])
 
         assert comment["content"] != c["content"]
         assert comment["content"] == content
+        assert comment["modified_at"] > comment["created_at"]
